@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 1999 S. Varshavchik.
 ** See COPYING for distribution information.
 */
 
@@ -15,11 +15,6 @@
 #include	<string.h>
 #include	<idn2.h>
 
-#if     HAS_GETHOSTNAME
-#else
-int gethostname(const char *, size_t);
-#endif
-
 static char *hostname_buf=0;
 
 const char *config_gethostname()
@@ -30,16 +25,19 @@ char	buf[BUFSIZ];
 	{
 		buf[sizeof(buf)-1]=0;
 		buf[0]=0;
-		gethostname(buf, sizeof(buf)-1);
+		gethostname_sys(buf, sizeof(buf)-1);
 
 		if (buf[0])
 		{
-			char *address_utf8;
+			char *address_utf8=0;
 
 			if (idna_to_unicode_8z8z(buf, &address_utf8, 0)
 			    != IDNA_SUCCESS)
+			{
+				if (address_utf8)
+					free(address_utf8);
 				address_utf8=courier_strdup(buf);
-
+			}
 			hostname_buf=ualllower(address_utf8);
 			free(address_utf8);
 		}
