@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 1999 S. Varshavchik.
 ** See COPYING for distribution information.
 */
 
@@ -18,23 +18,10 @@ const char *config_esmtpgreeting()
 
 		if ((esmtpidstring=readfile(f, 0)) == 0)
 		{
-			const char *me=config_me();
-			char *me_ace;
+			const char *me=config_me_ace();
 
-			if (idna_to_ascii_8z(me, &me_ace, 0) == IDNA_SUCCESS)
-			{
-				me=me_ace;
-			}
-			else
-			{
-				me_ace=0;
-			}
-
-			esmtpidstring=strcat(strcpy(courier_malloc(
+			esmtpidstring=strcat(strcpy((char *)courier_malloc(
 				strlen(me)+sizeof(" ESMTP")), me), " ESMTP");
-
-			if (me_ace)
-				free(me_ace);
 		}
 		free(f);
 	}
