@@ -10,7 +10,7 @@
 #endif
 #include	<courier-unicode.h>
 /*
-** Copyright 1998 - 2011 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2011 S. Varshavchik.  See COPYING for
 ** distribution information.
 */
 
@@ -30,7 +30,7 @@ struct wrap_info {
 	void (*output_func)(const char *p, size_t l, void *arg);
 	void *arg;
 
-	const unicode_char *uc;
+	const char32_t *uc;
 	size_t ucsize;
 
 	size_t cur_index;
